@@ -32,13 +32,13 @@ instaindex<-function(seq){
                 AG=1,AA=1,AL=1,LW=24.68,LC=1,LM=1,LH=1,LY=1,LF=1,LQ=33.6,LN=1,LI=1,LR=20.26,LD=1,LP=20.26,LT=1,LK=-7.49,
                 LE=1,LV=1,LS=1,LG=1,LA=1,LL=1,"NA"=1)
   # Divide the amino acid sequence in dipeptides
-  dp<-NULL
-  AA<-s2c(toupper(seq))
+  dp<-character(nchar(seq)-1)
+  AA<-strsplit(toupper(seq),"")[[1]]
   for (i in 1: (nchar(seq)-1)){
     dp[i]<-paste(AA[i:(i+1)],collapse = "")
   }
   # Apply the formula:
   # (10/L)*sum(DIWV(XiYi+1) for each dipeptide)
   # Return the index value rounded to 2 decimals
-  round((10/nchar(seq))*sum(guruprasad[dp],na.rm = TRUE),2)
+  (10/nchar(seq))*sum(guruprasad[dp],na.rm = TRUE)
 }
