@@ -8,9 +8,9 @@ test.charge <- function(){
   # COMPARED TO YADAMP
   # http://yadamp.unisa.it/showItem.aspx?yadampid=845&x=0,7055475
   # SEQUENCE: FLPVLAGLTPSIVPKLVCLLTKKC
-  checkEquals(round(charge("FLPVLAGLTPSIVPKLVCLLTKKC",5,pKscale = "Lehn"),1),3)
-  checkEquals(round(charge("FLPVLAGLTPSIVPKLVCLLTKKC",7,pKscale = "Lehn"),1),2.9)
-  checkEquals(round(charge("FLPVLAGLTPSIVPKLVCLLTKKC",9,pKscale = "Lehn"),1),1.0)
+  checkEquals(charge("FLPVLAGLTPSIVPKLVCLLTKKC",5,pKscale = "Lehn"),3,tolerance = 0.01)
+  checkEquals(charge("FLPVLAGLTPSIVPKLVCLLTKKC",7,pKscale = "Lehn"),2.9,tolerance = 0.01)
+  checkEquals(charge("FLPVLAGLTPSIVPKLVCLLTKKC",9,pKscale = "Lehn"),1.0,tolerance = 0.01)
   
   # CHECK OUTPUT CLASS
   checkTrue(is.numeric(charge("FLPVLAGLTPSIVPKLVCLLTKKC",7,pKscale = "Bjellqvist")))
